@@ -9,6 +9,7 @@ mod commit;
 mod commit_details;
 mod commit_files;
 mod commits_info;
+mod config;
 pub mod cred;
 pub mod diff;
 mod hooks;
@@ -44,6 +45,10 @@ pub use commit_files::get_commit_files;
 pub use commits_info::{
     get_commit_info, get_commits_info, CommitId, CommitInfo,
 };
+pub use config::{
+    get_config_string, untracked_files_config,
+    ShowUntrackedFilesConfig,
+};
 pub use diff::get_diff_commit;
 pub use hooks::{
     hooks_commit_msg, hooks_post_commit, hooks_pre_commit, HookResult,
@@ -79,7 +84,7 @@ mod tests {
     use super::{
         commit, stage_add_file,
         status::{get_status, StatusType},
-        utils::repo_write_file,
+        utils::{get_head_repo, repo, repo_write_file},
         CommitId, LogWalker,
     };
     use crate::error::Result;
@@ -128,6 +133,59 @@ mod tests {
             .unwrap()
     }
 
+    /// write, stage and commit a file giving the commit a specific timestamp
+    pub fn write_commit_file_at(
+        repo: &Repository,
+        file: &str,
+        content: &str,
+        commit_name: &str,
+        time: git2::Time,
+    ) -> CommitId {
+        repo_write_file(repo, file, content).unwrap();
+
+        let path = repo.workdir().unwrap().to_str().unwrap();
+
+        stage_add_file(path, Path::new(file)).unwrap();
+
+        commit_at(path, commit_name, time)
+    }
+
+    fn commit_at(
+        repo_path: &str,
+        msg: &str,
+        time: git2::Time,
+    ) -> CommitId {
+        let repo = repo(repo_path).unwrap();
+
+        let signature =
+            git2::Signature::new("name", "email", &time).unwrap();
+        let mut index = repo.index().unwrap();
+        let tree_id = index.write_tree().unwrap();
+        let tree = repo.find_tree(tree_id).unwrap();
+
+        let parents = if let Ok(id) = get_head_repo(&repo) {
+            vec![repo.find_commit(id.into()).unwrap()]
+        } else {
+            Vec::new()
+        };
+
+        let parents = parents.iter().collect::<Vec<_>>();
+
+        let commit = repo
+            .commit(
+                Some("HEAD"),
+                &signature,
+                &signature,
+                msg,
+                &tree,
+                parents.as_slice(),
+            )
+            .unwrap()
+            .into();
+
+        commit
+    }
+
     ///
     pub fn repo_init_empty() -> Result<(TempDir, Repository)> {
         sandbox_config_files();
@@ -197,12 +255,10 @@ mod tests {
     /// helper returning amount of files with changes in the (wd,stage)
     pub fn get_statuses(repo_path: &str) -> (usize, usize) {
         (
-            get_status(repo_path, StatusType::WorkingDir, true)
-                .unwrap()
-                .len(),
-            get_status(repo_path, StatusType::Stage, true)
+            get_status(repo_path, StatusType::WorkingDir)
                 .unwrap()
                 .len(),
+            get_status(repo_path, StatusType::Stage).unwrap().len(),
         )
     }
 
@@ -218,7 +274,10 @@ mod tests {
         max_count: usize,
     ) -> Vec<CommitId> {
         let mut commit_ids = Vec::<CommitId>::new();
-        LogWalker::new(r).read(&mut commit_ids, max_count).unwrap();
+        LogWalker::new(r, max_count)
+            .unwrap()
+            .read(&mut commit_ids)
+            .unwrap();
 
         commit_ids
     }
